GDrive class
Properties
-
debugLogList
↔ bool
-
Print file list in log
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
token
↔ String
-
Google OAuth access token. Will throw if empty.
getter/setter pair
Methods
-
create({required File file, required Media uploadMedia})
→ Future<File>
-
DriveApi.files.create wrapper
-
del(String fileId)
→ Future
-
DriveApi.files.del wrapper
-
get(String fileId, {DownloadOptions downloadOptions = defaultGDriveDownloadOptions})
→ Future<Object>
-
DriveApi.files.get wrapper
-
list({String fields = defaultGDriveFields, String orderBy = defaultGDriveOrderByModifiedTime, String spaces = defaultGDriveSpace, String? q})
→ Future<FileList>
-
DriveApi.files.list wrapper
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
searchLatest(String name)
→ Future<File>
-
Get the latest copy of a given file
-
toString()
→ String
-
A string representation of this object.
inherited